summaryrefslogtreecommitdiffstats
path: root/kdeprint/kdeprintfax
diff options
context:
space:
mode:
Diffstat (limited to 'kdeprint/kdeprintfax')
-rw-r--r--kdeprint/kdeprintfax/confgeneral.cpp20
-rw-r--r--kdeprint/kdeprintfax/confgeneral.h4
-rw-r--r--kdeprint/kdeprintfax/confsystem.cpp8
-rw-r--r--kdeprint/kdeprintfax/defcmds.cpp2
-rw-r--r--kdeprint/kdeprintfax/faxab.cpp2
-rw-r--r--kdeprint/kdeprintfax/faxctrl.cpp40
-rw-r--r--kdeprint/kdeprintfax/kdeprintfax.cpp6
7 files changed, 41 insertions, 41 deletions
diff --git a/kdeprint/kdeprintfax/confgeneral.cpp b/kdeprint/kdeprintfax/confgeneral.cpp
index 757c54af7..e19cdf94b 100644
--- a/kdeprint/kdeprintfax/confgeneral.cpp
+++ b/kdeprint/kdeprintfax/confgeneral.cpp
@@ -45,11 +45,11 @@ ConfGeneral::ConfGeneral(TQWidget *parent, const char *name)
QLabel *m_numberlabel = new TQLabel(i18n("N&umber:"), this);
m_numberlabel->setBuddy(m_number);
KSeparator *sep = new KSeparator( this );
- m_replace_int_char = new TQCheckBox( i18n( "Replace international prefix '+' with:" ), this );
- m_replace_int_char_val = new TQLineEdit( this );
- m_replace_int_char_val->setEnabled( false );
+ m_tqreplace_int_char = new TQCheckBox( i18n( "Replace international prefix '+' with:" ), this );
+ m_tqreplace_int_char_val = new TQLineEdit( this );
+ m_tqreplace_int_char_val->setEnabled( false );
- connect( m_replace_int_char, TQT_SIGNAL( toggled( bool ) ), m_replace_int_char_val, TQT_SLOT( setEnabled( bool ) ) );
+ connect( m_tqreplace_int_char, TQT_SIGNAL( toggled( bool ) ), m_tqreplace_int_char_val, TQT_SLOT( setEnabled( bool ) ) );
QGridLayout *l0 = new TQGridLayout(this, 6, 2, 10, 10);
l0->setColStretch(1, 1);
@@ -63,8 +63,8 @@ ConfGeneral::ConfGeneral(TQWidget *parent, const char *name)
l0->addMultiCellWidget( sep, 3, 3, 0, 1 );
TQHBoxLayout *l1 = new TQHBoxLayout( this, 0, 10 );
l0->addMultiCellLayout( l1, 4, 4, 0, 1 );
- l1->addWidget( m_replace_int_char );
- l1->addWidget( m_replace_int_char_val );
+ l1->addWidget( m_tqreplace_int_char );
+ l1->addWidget( m_tqreplace_int_char_val );
}
void ConfGeneral::load()
@@ -74,8 +74,8 @@ void ConfGeneral::load()
m_name->setText(conf->readEntry("Name", getenv("USER")));
m_number->setText(conf->readEntry("Number"));
m_company->setText(conf->readEntry("Company"));
- m_replace_int_char->setChecked( conf->readBoolEntry( "ReplaceIntChar", false ) );
- m_replace_int_char_val->setText( conf->readEntry( "ReplaceIntCharVal" ) );
+ m_tqreplace_int_char->setChecked( conf->readBoolEntry( "ReplaceIntChar", false ) );
+ m_tqreplace_int_char_val->setText( conf->readEntry( "ReplaceIntCharVal" ) );
}
void ConfGeneral::save()
@@ -85,6 +85,6 @@ void ConfGeneral::save()
conf->writeEntry("Name", m_name->text());
conf->writeEntry("Number", m_number->text());
conf->writeEntry("Company", m_company->text());
- conf->writeEntry( "ReplaceIntChar", m_replace_int_char->isChecked() );
- conf->writeEntry( "ReplaceIntCharVal", m_replace_int_char_val->text() );
+ conf->writeEntry( "ReplaceIntChar", m_tqreplace_int_char->isChecked() );
+ conf->writeEntry( "ReplaceIntCharVal", m_tqreplace_int_char_val->text() );
}
diff --git a/kdeprint/kdeprintfax/confgeneral.h b/kdeprint/kdeprintfax/confgeneral.h
index 5a3ee6ca9..da5bba2e0 100644
--- a/kdeprint/kdeprintfax/confgeneral.h
+++ b/kdeprint/kdeprintfax/confgeneral.h
@@ -36,8 +36,8 @@ public:
private:
QLineEdit *m_name, *m_company, *m_number;
- TQCheckBox *m_replace_int_char;
- TQLineEdit *m_replace_int_char_val;
+ TQCheckBox *m_tqreplace_int_char;
+ TQLineEdit *m_tqreplace_int_char_val;
};
#endif
diff --git a/kdeprint/kdeprintfax/confsystem.cpp b/kdeprint/kdeprintfax/confsystem.cpp
index 51ea326c8..0a0a4968d 100644
--- a/kdeprint/kdeprintfax/confsystem.cpp
+++ b/kdeprint/kdeprintfax/confsystem.cpp
@@ -178,13 +178,13 @@ void ConfSystem::slotSystemChanged(int ID)
m_commands[m_current] = m_command->text();
m_current = ID;
if (ID == EFAX_ID)
- m_device->parentWidget()->show();
+ m_device->tqparentWidget()->show();
else
- m_device->parentWidget()->hide();
+ m_device->tqparentWidget()->hide();
if (ID == HYLAFAX_ID)
- m_server->parentWidget()->show();
+ m_server->tqparentWidget()->show();
else
- m_server->parentWidget()->hide();
+ m_server->tqparentWidget()->hide();
m_command->setText(m_commands[m_current]);
}
diff --git a/kdeprint/kdeprintfax/defcmds.cpp b/kdeprint/kdeprintfax/defcmds.cpp
index 09631b51d..f0f5cfdd5 100644
--- a/kdeprint/kdeprintfax/defcmds.cpp
+++ b/kdeprint/kdeprintfax/defcmds.cpp
@@ -32,7 +32,7 @@ TQString defaultCommand(const TQString& cmd)
QString exe = KStandardDirs::findExe(r.cap(1));
if (exe.isEmpty())
exe = "/usr/bin/"+r.cap(1);
- str.replace(p, r.matchedLength(), exe);
+ str.tqreplace(p, r.matchedLength(), exe);
}
return str;
}
diff --git a/kdeprint/kdeprintfax/faxab.cpp b/kdeprint/kdeprintfax/faxab.cpp
index ebd6b9cb2..49a9be89e 100644
--- a/kdeprint/kdeprintfax/faxab.cpp
+++ b/kdeprint/kdeprintfax/faxab.cpp
@@ -163,7 +163,7 @@ bool FaxAB::getEntry(TQStringList& number, TQStringList& name, TQStringList& ent
/*
number = kab.m_fax->currentText();
name = kab.m_name->currentText();
- if (kab.m_entries.contains(name))
+ if (kab.m_entries.tqcontains(name))
{
enterprise = kab.m_entries[name][0];
}
diff --git a/kdeprint/kdeprintfax/kdeprintfax.cpp b/kdeprint/kdeprintfax/kdeprintfax.cpp
index a5f66992b..81f144b9a 100644
--- a/kdeprint/kdeprintfax/kdeprintfax.cpp
+++ b/kdeprint/kdeprintfax/kdeprintfax.cpp
@@ -429,14 +429,14 @@ void KdeprintFax::updateState()
if ( !m_cover->isEnabled() )
m_cover->setChecked(false);
m_comment->setEnabled(cmd.find("%comment") != -1 && m_cover->isChecked());
- //m_comment->setPaper(m_comment->isEnabled() ? colorGroup().brush(TQColorGroup::Base) : colorGroup().brush(TQColorGroup::Background));
+ //m_comment->setPaper(m_comment->isEnabled() ? tqcolorGroup().brush(TQColorGroup::Base) : tqcolorGroup().brush(TQColorGroup::Background));
if (!m_comment->isEnabled())
{
m_comment->setText("");
- m_comment->setPaper( colorGroup().background() );
+ m_comment->setPaper( tqcolorGroup().background() );
}
else
- m_comment->setPaper( colorGroup().base() );
+ m_comment->setPaper( tqcolorGroup().base() );
/*
m_enterprise->setEnabled(cmd.find("%enterprise") != -1);
if (!m_enterprise->isEnabled())
diff --git a/kdeprint/kdeprintfax/faxctrl.cpp b/kdeprint/kdeprintfax/faxctrl.cpp
index 1d1cd1fa5..6638c1b7f 100644
--- a/kdeprint/kdeprintfax/faxctrl.cpp
+++ b/kdeprint/kdeprintfax/faxctrl.cpp
@@ -87,9 +87,9 @@ static TQString stripNumber( const TQString& s )
// removes any non-numeric character, except ('+','*','#') (hope it's supported by faxing tools)
TQString strip_s = s;
- strip_s.replace( TQRegExp( "[^\\d+*#]" ), "" );
+ strip_s.tqreplace( TQRegExp( "[^\\d+*#]" ), "" );
if ( strip_s.find( '+' ) != -1 && conf->readBoolEntry( "ReplaceIntChar", false ) )
- strip_s.replace( "+", conf->readEntry( "ReplaceIntCharVal" ) );
+ strip_s.tqreplace( "+", conf->readEntry( "ReplaceIntCharVal" ) );
return strip_s;
}
@@ -172,7 +172,7 @@ static TQString processTag( const TQString& match, const TQString& value )
if ( match[ p+1 ] == '{' )
{
v = match.mid( p+2, match.length()-p-3 );
- v.replace( "@@", quote( value ) );
+ v.tqreplace( "@@", quote( value ) );
}
else
v = ( "-" + match.mid( p+1 ) + " " + quote( value ) );
@@ -188,9 +188,9 @@ static bool isTag( const TQString& m, const TQString& t )
return ( m == t || m.startsWith( t+"_" ) );
}
-static TQString replaceTags( const TQString& s, const TQString& tags, KdeprintFax *fax = NULL, const KdeprintFax::FaxItem& item = KdeprintFax::FaxItem() )
+static TQString tqreplaceTags( const TQString& s, const TQString& tags, KdeprintFax *fax = NULL, const KdeprintFax::FaxItem& item = KdeprintFax::FaxItem() )
{
- // unquote variables (they will be replaced with quoted values later)
+ // unquote variables (they will be tqreplaced with quoted values later)
TQValueStack<bool> stack;
KConfig *conf = KGlobal::config();
@@ -244,7 +244,7 @@ static TQString replaceTags( const TQString& s, const TQString& tags, KdeprintFa
else if (cmd[i]=='`')
{
// Replace all `...` with safer $(...)
- cmd.replace (i, 1, "$(");
+ cmd.tqreplace (i, 1, "$(");
TQRegExp re_backticks("(`|\\\\`|\\\\\\\\|\\\\\\$)");
for ( int i2=re_backticks.search(cmd,i+2);
i2!=-1;
@@ -253,7 +253,7 @@ static TQString replaceTags( const TQString& s, const TQString& tags, KdeprintFa
{
if (cmd[i2] == '`')
{
- cmd.replace (i2, 1, ")");
+ cmd.tqreplace (i2, 1, ")");
i2=cmd.length(); // leave loop
}
else
@@ -291,7 +291,7 @@ static TQString replaceTags( const TQString& s, const TQString& tags, KdeprintFa
if (v.isEmpty())
v = getenv("FAXSERVER");
if (v.isEmpty())
- v = TQString::fromLatin1("localhost");
+ v = TQString::tqfromLatin1("localhost");
v = processTag( match, v );
}
else if (isTag( match, "%page" ))
@@ -343,7 +343,7 @@ static TQString replaceTags( const TQString& s, const TQString& tags, KdeprintFa
else if (issinglequote)
v="'"+v+"'";
- cmd.replace (i, match.length(), v);
+ cmd.tqreplace (i, match.length(), v);
i+=v.length();
}
}
@@ -375,8 +375,8 @@ bool FaxCtrl::send(KdeprintFax *f)
if (m_command.isEmpty())
return false;
- // replace tags common to all fax "operations"
- m_command = replaceTags( m_command, tagList( 11, "%dev", "%server", "%page", "%res", "%user", "%from", "%email", "%comment", "%time", "%subject", "%cover" ), f );
+ // tqreplace tags common to all fax "operations"
+ m_command = tqreplaceTags( m_command, tagList( 11, "%dev", "%server", "%page", "%res", "%user", "%from", "%email", "%comment", "%time", "%subject", "%cover" ), f );
m_log = TQString::null;
m_filteredfiles.clear();
@@ -447,11 +447,11 @@ void FaxCtrl::sendFax()
{
if ( m_command.find( "%files" ) != -1 )
{
- // replace %files tag
+ // tqreplace %files tag
QString filestr;
for (TQStringList::ConstIterator it=m_filteredfiles.begin(); it!=m_filteredfiles.end(); ++it)
filestr += (quote(*it)+" ");
- m_command.replace("%files", filestr);
+ m_command.tqreplace("%files", filestr);
}
if ( !m_faxlist.isEmpty() )
@@ -461,7 +461,7 @@ void FaxCtrl::sendFax()
addLogTitle( i18n( "Sending fax to %1 (%2)" ).arg( item.number ).arg( item.name ) );
- TQString cmd = replaceTags( m_command, tagList( 4, "%number", "%name", "%enterprise", "%rawnumber" ), NULL, item );
+ TQString cmd = tqreplaceTags( m_command, tagList( 4, "%number", "%name", "%enterprise", "%rawnumber" ), NULL, item );
m_process->clearArguments();
*m_process << cmd;
addLog(i18n("Sending to fax using: %1").arg(cmd));
@@ -491,7 +491,7 @@ void FaxCtrl::filter()
m_tempfiles.append(tmp);
m_process->clearArguments();
*m_process << locate("data","kdeprintfax/anytops") << "-m" << KProcess::quote(locate("data","kdeprintfax/faxfilters"))
- << TQString::fromLatin1("--mime=%1").arg(mimeType)
+ << TQString::tqfromLatin1("--mime=%1").arg(mimeType)
<< "-p" << pageSize()
<< KProcess::quote(m_files[0]) << KProcess::quote(tmp);
if (!m_process->start(KProcess::NotifyOnExit, KProcess::AllOutput))
@@ -553,7 +553,7 @@ void FaxCtrl::viewLog(TQWidget *)
}
else
{
- KWin::activateWindow(m_logview->parentWidget()->winId());
+ KWin::activateWindow(m_logview->tqparentWidget()->winId());
}
}
@@ -605,7 +605,7 @@ void FaxCtrl::slotCloseLog()
QTextEdit *view = m_logview;
m_logview = 0;
if (obj && obj->inherits("QPushButton"))
- delete view->parentWidget();
+ delete view->tqparentWidget();
kdDebug() << "slotClose()" << endl;
}
}
@@ -617,7 +617,7 @@ void FaxCtrl::slotPrintLog()
KPrinter printer;
printer.setDocName( i18n( "Fax log" ) );
printer.setDocFileName( "faxlog" );
- if ( printer.setup( m_logview->topLevelWidget(), i18n( "Fax Log" ) ) )
+ if ( printer.setup( m_logview->tqtopLevelWidget(), i18n( "Fax Log" ) ) )
{
TQPainter painter( &printer );
TQPaintDeviceMetrics metric( &printer );
@@ -625,7 +625,7 @@ void FaxCtrl::slotPrintLog()
//TQString txt = m_logview->text();
TQString txt = m_log;
- txt.replace( '\n', "<br>" );
+ txt.tqreplace( '\n', "<br>" );
txt.prepend( "<h2>" + i18n( "KDEPrint Fax Tool Log" ) + "</h2>" );
kdDebug() << "Log: " << txt << endl;
@@ -634,7 +634,7 @@ void FaxCtrl::slotPrintLog()
richText.setWidth( &painter, body.width() );
do
{
- richText.draw( &painter, body.left(), body.top(), view, m_logview->colorGroup() );
+ richText.draw( &painter, body.left(), body.top(), view, m_logview->tqcolorGroup() );
view.moveBy( 0, body.height() );
painter.translate( 0, -body.height() );
if ( view.top() >= richText.height() )